@@ -3,7 +3,7 @@ from skeleton.settings import *
 
 DATABASES = {
     'default': {
-        'ENGINE': 'django.db.backends.postgresql_psycopg2',
+        'ENGINE': 'django.contrib.gis.db.backends.postgis',
         'NAME': 'skeleton_qa',
         'USER': 'skeleton_qa',
         'PASSWORD': 'skeleton_qa',
